NFD+model+apps+helper+tests: Upgrade NFD and related changes

Based on NFD:commit:2fc649bfc67b93b4191cfbee5bcd70330bfb48f0 (version 0.3.4)

Change-Id: I89f5182600467171797af4f8f83e1edffe14ad95
Refs: #3125
diff --git a/examples/ndn-grid-multiple-strategies.cpp b/examples/ndn-grid-multiple-strategies.cpp
index 06f3a1c..3f14548 100644
--- a/examples/ndn-grid-multiple-strategies.cpp
+++ b/examples/ndn-grid-multiple-strategies.cpp
@@ -35,7 +35,7 @@
  * This scenario simulates a grid topology (using PointToPointGrid module)
  *
  * The first six nodes use the best route forwarding strategy, whereas
  * the three remaining nodes use the broadcast forwarding strategy.
  *
  * (consumer) -- ( ) ----- ( )
  *     |          |         |
@@ -99,7 +99,7 @@
                                       "/localhost/nfd/strategy/best-route");
       else
         StrategyChoiceHelper::Install(grid.GetNode(row, column), "/prefix",
-                                      "/localhost/nfd/strategy/broadcast");
+                                      "/localhost/nfd/strategy/multicast");
     }
   }
@@ -35,7 +35,7 @@
  *
  * The first six nodes use the best route forwarding strategy, whereas
- * the three remaining nodes use the broadcast forwarding strategy.
+ * the three remaining nodes use the multicast forwarding strategy.
  *
  * (consumer) -- ( ) ----- ( )